import os
import json
import logging
import re
import uuid
import boto3
import requests
from botocore.config import Config
from io import BytesIO
from datetime import datetime
from openai import OpenAI

# 导入配置和业务逻辑模块
from app.config.config import DevelopmentConfig, ProductionConfig
from app.core.data_parse.parse import (
    BusinessCard, check_duplicate_business_card, 
    create_main_card_with_duplicates, update_career_path,
    normalize_mobile_numbers, ParseTaskRepository
)
from app import db

# 使用配置变量,缺省认为在生产环境运行
config = ProductionConfig()
# 使用配置变量
minio_url = f"{'https' if config.MINIO_SECURE else 'http'}://{config.MINIO_HOST}"
minio_access_key = config.MINIO_USER
minio_secret_key = config.MINIO_PASSWORD
minio_bucket = config.MINIO_BUCKET
use_ssl = config.MINIO_SECURE


def get_minio_client():
    """获取MinIO客户端连接"""
    try:
        logging.info(f"尝试连接MinIO服务器: {minio_url}")
        
        minio_client = boto3.client(
            's3',
            endpoint_url=minio_url,
            aws_access_key_id=minio_access_key,
            aws_secret_access_key=minio_secret_key,
            config=Config(
                signature_version='s3v4',
                retries={'max_attempts': 3, 'mode': 'standard'},
                connect_timeout=10,
                read_timeout=30
            )
        )
        
        # 确保存储桶存在
        buckets = minio_client.list_buckets()
        bucket_names = [bucket['Name'] for bucket in buckets.get('Buckets', [])]
        logging.info(f"成功连接到MinIO服务器，现有存储桶: {bucket_names}")
        
        if minio_bucket not in bucket_names:
            logging.info(f"创建存储桶: {minio_bucket}")
            minio_client.create_bucket(Bucket=minio_bucket)
            
        return minio_client
    except Exception as e:
        logging.error(f"MinIO连接错误: {str(e)}")
        return None


def upload_md_to_minio(web_md, filename=None):
    """
    将markdown文本上传到MinIO
    
    Args:
        web_md (str): markdown格式的文本内容
        filename (str, optional): 指定的文件名，如果不提供则自动生成
        
    Returns:
        str: MinIO中的文件路径，如果上传失败返回None
    """
    try:
        # 生成文件名
        if not filename:
            timestamp = datetime.now().strftime('%Y%m%d_%H%M%S')
            unique_id = uuid.uuid4().hex[:8]
            filename = f"webpage_talent_{timestamp}_{unique_id}.md"
        elif not filename.endswith('.md'):
            filename += '.md'
        
        # 获取MinIO客户端
        minio_client = get_minio_client()
        if not minio_client:
            logging.error("无法获取MinIO客户端")
            return None
        
        # 将文本转换为字节流
        md_bytes = web_md.encode('utf-8')
        md_stream = BytesIO(md_bytes)
        
        # 上传到MinIO
        minio_path = f"webpage_talent/{filename}"
        logging.info(f"开始上传MD文件到MinIO: {minio_path}")
        
        minio_client.put_object(
            Bucket=minio_bucket,
            Key=minio_path,
            Body=md_stream,
            ContentType='text/markdown',
            Metadata={
                'original_filename': filename,
                'upload_time': datetime.now().isoformat(),
                'content_type': 'webpage_talent_md'
            }
        )
        
        logging.info(f"MD文件成功上传到MinIO: {minio_path}")
        return minio_path
        
    except Exception as e:
        logging.error(f"上传MD文件到MinIO失败: {str(e)}", exc_info=True)
        return None


def add_webpage_talent(talent_list, web_md):
    """
    添加网页人才信息，包括保存网页内容和创建名片记录
    
    Args:
        talent_list (list): 人才信息列表，每个item包含业务卡片格式的数据
        web_md (str): 网页markdown文本内容
        
    Returns:
        dict: 处理结果，包含成功和失败的记录统计
    """
    try:
        # 参数验证
        if not talent_list or not isinstance(talent_list, list):
            return {
                'code': 400,
                'success': False,
                'message': 'talent_list参数必须是非空数组',
                'data': None
            }
        
        if not web_md or not isinstance(web_md, str):
            return {
                'code': 400,
                'success': False,
                'message': 'web_md参数必须是非空字符串',
                'data': None
            }
        
        # 上传markdown文件到MinIO
        logging.info("开始上传网页内容到MinIO")
        minio_md_path = upload_md_to_minio(web_md)
        
        if not minio_md_path:
            return {
                'code': 500,
                'success': False,
                'message': '上传网页内容到MinIO失败',
                'data': None
            }
        
        # 处理结果统计
        results = {
            'total_count': len(talent_list),
            'success_count': 0,
            'failed_count': 0,
            'success_records': [],
            'failed_records': [],
            'minio_md_path': minio_md_path
        }
        
        # 循环处理每个人才记录
        for index, talent_data in enumerate(talent_list):
            try:
                logging.info(f"开始处理第{index + 1}个人才记录: {talent_data.get('name_zh', 'Unknown')}")
                
                # 验证必要字段
                if not talent_data.get('name_zh'):
                    error_msg = f"第{index + 1}个记录缺少name_zh字段"
                    logging.warning(error_msg)
                    results['failed_records'].append({
                        'index': index + 1,
                        'data': talent_data,
                        'error': error_msg
                    })
                    results['failed_count'] += 1
                    continue
                
                # 设置origin_source为原始资料记录
                talent_data['origin_source'] = {
                    'type': 'webpage_talent',
                    'minio_path': minio_md_path,
                    'source_date': datetime.now().strftime('%Y-%m-%d %H:%M:%S')
                }
                
                # 处理business_card记录
                card_result = process_single_talent_card(talent_data, minio_md_path)
                
                if card_result['success']:
                    results['success_records'].append({
                        'index': index + 1,
                        'data': card_result['data'],
                        'message': card_result['message']
                    })
                    results['success_count'] += 1
                    logging.info(f"成功处理第{index + 1}个人才记录")
                else:
                    results['failed_records'].append({
                        'index': index + 1,
                        'data': talent_data,
                        'error': card_result['message']
                    })
                    results['failed_count'] += 1
                    logging.error(f"处理第{index + 1}个人才记录失败: {card_result['message']}")
                    
            except Exception as e:
                error_msg = f"处理第{index + 1}个人才记录时发生异常: {str(e)}"
                logging.error(error_msg, exc_info=True)
                results['failed_records'].append({
                    'index': index + 1,
                    'data': talent_data,
                    'error': error_msg
                })
                results['failed_count'] += 1
        
        # 生成最终结果
        if results['success_count'] == results['total_count']:
            # 全部成功时，返回业务卡片记录数组，与add_business_card保持一致
            success_data = [record['data'] for record in results['success_records']]
            return {
                'code': 200,
                'success': True,
                'message': f'所有{results["total_count"]}条人才记录处理成功',
                'data': success_data
            }
        elif results['success_count'] > 0:
            return {
                'code': 206,  # Partial Content
                'success': True,
                'message': f'部分处理成功：{results["success_count"]}/{results["total_count"]}条记录成功',
                'data': results
            }
        else:
            return {
                'code': 500,
                'success': False,
                'message': f'所有{results["total_count"]}条人才记录处理失败',
                'data': results
            }
            
    except Exception as e:
        error_msg = f"add_webpage_talent函数执行失败: {str(e)}"
        logging.error(error_msg, exc_info=True)
        return {
            'code': 500,
            'success': False,
            'message': error_msg,
            'data': None
        }


def download_and_upload_image_to_minio(pic_url, person_name):
    """
    从URL下载图片并上传到MinIO
    
    Args:
        pic_url (str): 图片的URL地址
        person_name (str): 人员姓名，用于生成文件名
        
    Returns:
        str: MinIO中的图片路径，如果失败返回None
    """
    try:
        if not pic_url or not pic_url.strip():
            logging.info("pic_url为空，跳过图片下载")
            return None
            
        # 验证URL格式
        if not pic_url.startswith(('http://', 'https://')):
            logging.warning(f"无效的图片URL格式: {pic_url}")
            return None
        
        logging.info(f"开始下载图片: {pic_url}")
        
        # 设置请求头，模拟浏览器请求
        headers = {
            'User-Agent': 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/91.0.4472.124 Safari/537.36'
        }
        
        # 下载图片
        response = requests.get(pic_url, headers=headers, timeout=30)
        response.raise_for_status()
        
        # 检查响应内容类型
        content_type = response.headers.get('content-type', '').lower()
        if not content_type.startswith('image/'):
            logging.warning(f"URL返回的不是图片内容，content-type: {content_type}")
            return None
        
        # 获取图片数据
        image_data = response.content
        if len(image_data) == 0:
            logging.warning("下载的图片数据为空")
            return None
        
        # 从URL或content-type推断文件扩展名
        file_extension = '.jpg'  # 默认扩展名
        if 'png' in content_type:
            file_extension = '.png'
        elif 'gif' in content_type:
            file_extension = '.gif'
        elif 'webp' in content_type:
            file_extension = '.webp'
        elif pic_url.lower().endswith(('.jpg', '.jpeg', '.png', '.gif', '.webp')):
            file_extension = '.' + pic_url.split('.')[-1].lower()
        
        # 生成文件名
        timestamp = datetime.now().strftime('%Y%m%d_%H%M%S')
        unique_id = uuid.uuid4().hex[:8]
        safe_name = re.sub(r'[^\w\s-]', '', person_name.replace(' ', '_'))[:20]  # 清理人名用作文件名
        filename = f"talent_photo_{safe_name}_{timestamp}_{unique_id}{file_extension}"
        
        # 获取MinIO客户端
        minio_client = get_minio_client()
        if not minio_client:
            logging.error("无法获取MinIO客户端")
            return None
        
        # 将图片数据转换为字节流
        image_stream = BytesIO(image_data)
        
        # 上传到MinIO
        minio_path = f"talent_photos/{filename}"
        logging.info(f"开始上传图片到MinIO: {minio_path}")
        
        minio_client.put_object(
            Bucket=minio_bucket,
            Key=minio_path,
            Body=image_stream,
            ContentType=content_type,
            Metadata={
                'original_url': pic_url,
                'person_name': person_name,
                'upload_time': datetime.now().isoformat(),
                'content_type': 'talent_photo'
            }
        )
        
        logging.info(f"图片成功上传到MinIO: {minio_path}")
        return minio_path
        
    except requests.RequestException as e:
        logging.error(f"下载图片失败 ({pic_url}): {str(e)}")
        return None
    except Exception as e:
        logging.error(f"上传图片到MinIO失败: {str(e)}", exc_info=True)
        return None


def process_single_talent_card(talent_data, minio_md_path):
    """
    处理单个人才的名片记录创建
    
    Args:
        talent_data (dict): 人才信息数据
        minio_md_path (str): MinIO中网页内容的路径
        
    Returns:
        dict: 处理结果
    """
    try:
        # 下载并上传图片到MinIO
        image_path = None
        if talent_data.get('pic_url'):
            person_name = talent_data.get('name_zh', 'unknown')
            image_path = download_and_upload_image_to_minio(talent_data['pic_url'], person_name)
            if image_path:
                logging.info(f"成功处理人员 {person_name} 的图片，MinIO路径: {image_path}")
            else:
                logging.warning(f"人员 {person_name} 的图片处理失败")
        
        # 检查重复记录
        try:
            duplicate_check = check_duplicate_business_card(talent_data)
            logging.info(f"重复记录检查结果: {duplicate_check['reason']}")
        except Exception as e:
            logging.error(f"重复记录检查失败: {str(e)}", exc_info=True)
            # 如果检查失败，默认创建新记录
            duplicate_check = {
                'is_duplicate': False,
                'action': 'create_new',
                'existing_card': None,
                'reason': f'重复检查失败，创建新记录: {str(e)}'
            }
        
        # 根据重复检查结果执行不同操作
        if duplicate_check['action'] == 'update':
            # 更新现有记录
            existing_card = duplicate_check['existing_card']
            
            # 更新基本信息
            existing_card.name_en = talent_data.get('name_en', existing_card.name_en)
            existing_card.title_zh = talent_data.get('title_zh', existing_card.title_zh)
            existing_card.title_en = talent_data.get('title_en', existing_card.title_en)
            
            # 处理手机号码字段，支持多个手机号码
            if 'mobile' in talent_data:
                new_mobile = normalize_mobile_numbers(talent_data.get('mobile', ''))
                if new_mobile:
                    # 合并手机号码
                    from app.core.data_parse.parse import merge_mobile_numbers
                    existing_card.mobile = merge_mobile_numbers(existing_card.mobile, new_mobile)
                elif talent_data.get('mobile') == '':
                    existing_card.mobile = ''
            
            existing_card.phone = talent_data.get('phone', existing_card.phone)
            existing_card.email = talent_data.get('email', existing_card.email)
            existing_card.hotel_zh = talent_data.get('hotel_zh', existing_card.hotel_zh)
            existing_card.hotel_en = talent_data.get('hotel_en', existing_card.hotel_en)
            existing_card.address_zh = talent_data.get('address_zh', existing_card.address_zh)
            existing_card.address_en = talent_data.get('address_en', existing_card.address_en)
            existing_card.postal_code_zh = talent_data.get('postal_code_zh', existing_card.postal_code_zh)
            existing_card.postal_code_en = talent_data.get('postal_code_en', existing_card.postal_code_en)
            existing_card.brand_zh = talent_data.get('brand_zh', existing_card.brand_zh)
            existing_card.brand_en = talent_data.get('brand_en', existing_card.brand_en)
            existing_card.affiliation_zh = talent_data.get('affiliation_zh', existing_card.affiliation_zh)
            existing_card.affiliation_en = talent_data.get('affiliation_en', existing_card.affiliation_en)
            
            # 处理生日字段
            if talent_data.get('birthday'):
                try:
                    existing_card.birthday = datetime.strptime(talent_data.get('birthday'), '%Y-%m-%d').date()
                except ValueError:
                    # 如果日期格式不正确，保持原值
                    pass
            
            # 处理年龄字段
            if 'age' in talent_data:
                try:
                    if talent_data['age'] is not None and str(talent_data['age']).strip():
                        age_value = int(talent_data['age'])
                        if 0 < age_value <= 150:  # 合理的年龄范围检查
                            existing_card.age = age_value
                    else:
                        existing_card.age = None
                except (ValueError, TypeError):
                    # 如果年龄格式不正确，保持原值
                    pass
            
            existing_card.native_place = talent_data.get('native_place', existing_card.native_place)
            existing_card.residence = talent_data.get('residence', existing_card.residence)
            existing_card.brand_group = talent_data.get('brand_group', existing_card.brand_group)
            existing_card.updated_by = 'webpage_talent_system'
            
            # 更新图片路径
            if image_path:
                existing_card.image_path = image_path
            
            # 更新人才档案
            if talent_data.get('talent_profile'):
                existing_card.talent_profile = talent_data.get('talent_profile')
            
            # 设置origin_source为原始资料记录
            existing_card.origin_source = {
                'type': 'webpage_talent',
                'minio_path': minio_md_path,
                'source_date': datetime.now().strftime('%Y-%m-%d %H:%M:%S')
            }
            
            # 更新职业轨迹，传递图片路径
            existing_card.career_path = update_career_path(existing_card, talent_data, image_path=image_path or '')
            
            db.session.commit()
            
            logging.info(f"已更新现有名片记录，ID: {existing_card.id}")
            
            return {
                'success': True,
                'message': f'名片信息已更新。{duplicate_check["reason"]}',
                'data': existing_card.to_dict()
            }
            
        elif duplicate_check['action'] == 'create_with_duplicates':
            # 创建新记录作为主记录，并保存疑似重复记录信息
            main_card, duplicate_record = create_main_card_with_duplicates(
                talent_data, 
                image_path,  # 传递图片路径
                duplicate_check['suspected_duplicates'],
                duplicate_check['reason']
            )
            
            main_card.updated_by = 'webpage_talent_system'
            
            # 设置origin_source为原始资料记录
            main_card.origin_source = {
                'type': 'webpage_talent',
                'minio_path': minio_md_path,
                'source_date': datetime.now().strftime('%Y-%m-%d %H:%M:%S')
            }
            db.session.commit()
            
            return {
                'success': True,
                'message': f'创建新记录成功，发现疑似重复记录待处理。{duplicate_check["reason"]}',
                'data': {
                    'main_card': main_card.to_dict(),
                    'duplicate_record_id': duplicate_record.id,
                    'suspected_duplicates_count': len(duplicate_check['suspected_duplicates']),
                    'processing_status': 'pending',
                    'duplicate_reason': duplicate_record.duplicate_reason,
                    'created_at': duplicate_record.created_at.strftime('%Y-%m-%d %H:%M:%S')
                }
            }
            
        else:
            # 创建新记录
            # 准备初始职业轨迹
            initial_entry = {
                'date': datetime.now().strftime('%Y-%m-%d'),
                'hotel_zh': talent_data.get('hotel_zh', ''),
                'hotel_en': talent_data.get('hotel_en', ''),
                'title_zh': talent_data.get('title_zh', ''),
                'title_en': talent_data.get('title_en', ''),
                'image_path': image_path or '',  # 使用下载的图片路径
                'source': 'webpage_extraction'
            }
            initial_career_path = [initial_entry]
            
            # 处理年龄字段，确保是有效的整数或None
            age_value = None
            if talent_data.get('age'):
                try:
                    age_value = int(talent_data.get('age'))
                    if age_value <= 0 or age_value > 150:  # 合理的年龄范围检查
                        age_value = None
                except (ValueError, TypeError):
                    age_value = None
            
            business_card = BusinessCard(
                name_zh=talent_data.get('name_zh', ''),
                name_en=talent_data.get('name_en', ''),
                title_zh=talent_data.get('title_zh', ''),
                title_en=talent_data.get('title_en', ''),
                mobile=normalize_mobile_numbers(talent_data.get('mobile', '')),
                phone=talent_data.get('phone', ''),
                email=talent_data.get('email', ''),
                hotel_zh=talent_data.get('hotel_zh', ''),
                hotel_en=talent_data.get('hotel_en', ''),
                address_zh=talent_data.get('address_zh', ''),
                address_en=talent_data.get('address_en', ''),
                postal_code_zh=talent_data.get('postal_code_zh', ''),
                postal_code_en=talent_data.get('postal_code_en', ''),
                brand_zh=talent_data.get('brand_zh', ''),
                brand_en=talent_data.get('brand_en', ''),
                affiliation_zh=talent_data.get('affiliation_zh', ''),
                affiliation_en=talent_data.get('affiliation_en', ''),
                birthday=datetime.strptime(talent_data.get('birthday'), '%Y-%m-%d').date() if talent_data.get('birthday') else None,
                age=age_value,
                native_place=talent_data.get('native_place', ''),
                residence=talent_data.get('residence', ''),
                image_path=image_path,  # 使用下载的图片路径
                career_path=initial_career_path,
                brand_group=talent_data.get('brand_group', ''),
                origin_source={
                    'type': 'webpage_talent',
                    'minio_path': minio_md_path,
                    'source_date': datetime.now().strftime('%Y-%m-%d %H:%M:%S')
                },
                talent_profile=talent_data.get('talent_profile', ''),  # 人才档案
                status='active',
                updated_by='webpage_talent_system'
            )
            
            db.session.add(business_card)
            db.session.commit()
            
            logging.info(f"名片信息已保存到数据库，ID: {business_card.id}")
            
            return {
                'success': True,
                'message': f'名片信息保存成功。{duplicate_check["reason"]}',
                'data': business_card.to_dict()
            }
            
    except Exception as e:
        db.session.rollback()
        error_msg = f"处理单个人才名片记录失败: {str(e)}"
        logging.error(error_msg, exc_info=True)
        
        return {
            'success': False,
            'message': error_msg,
            'data': None
        }


def process_webpage_with_QWen(markdown_text, publish_time):
    """
    使用阿里云的 Qwen VL Max 模型解析网页 markdown 文本中的名片信息
    
    Args:
        markdown_text (str): 网页的 markdown 格式文本内容
        publish_time (str): 发布时间，用于career_path中的date字段
        
    Returns:
        dict: 解析的名片信息
    """
    # 阿里云 Qwen API 配置
    QWEN_API_KEY = os.environ.get('QWEN_API_KEY', 'sk-8f2320dafc9e4076968accdd8eebd8e9')
    
    try:
        # 初始化 OpenAI 客户端，配置为阿里云 API
        client = OpenAI(
            api_key=QWEN_API_KEY,
            base_url="https://dashscope.aliyuncs.com/compatible-mode/v1",
        )
        
        # 构建针对网页文本的优化提示语
        prompt = """你是酒店行业人事任命信息提取专家。请仔细分析提供的网页Markdown文本内容，精确提取其中的人员任命信息。

## 重要说明
1. **多人员处理**: 文本中可能包含多个人的任命信息，通常以数字编号（如**1**、**2**、**3**等）分隔不同人员。请将所有人员信息都提取出来，以JSON数组格式返回。请仔细查看整个文档，不要遗漏任何人员信息。
2. **照片链接识别**: 人物照片链接通常出现在人物姓名的前面，通过空行分隔。请优先关联距离最近的照片链接。
3. **字段限制**: 只需要提取指定的9个字段，其他信息忽略。
4. **完整性要求**: 请确保提取文档中所有被任命的人员信息，包括总经理、副总裁、总监等各级管理人员。每个数字编号下的人员都需要提取。

## 提取要求
- 区分中英文内容，分别提取
- 保持提取信息的原始格式（如大小写、标点）
- 对于无法识别或文本中不存在的信息，返回空字符串
- 文本中没有的信息，请不要猜测
- 从酒店任命公告中识别人员基本信息和职位信息

## 照片链接识别规则
- 照片通常以 ![描述](URL) 格式出现
- 照片链接通常位于人物姓名的前面，通过空行分隔
- 每个人物对应其前面最近的一张照片
- 如果照片无法明确对应某个人物，则该人物的pic_url为空字符串

## 需提取的字段（仅这9个字段）
1. 中文姓名 (name_zh) - 人物的中文姓名
2. 英文姓名 (name_en) - 人物的英文姓名，如果没有则为空字符串
3. 中文职位/头衔 (title_zh) - 人物的中文职位或头衔
4. 英文职位/头衔 (title_en) - 人物的英文职位或头衔，如果没有则为空字符串
5. 中文酒店/公司名称 (hotel_zh) - 人物所在的中文酒店或公司名称
6. 英文酒店/公司名称 (hotel_en) - 人物所在的英文酒店或公司名称，如果没有则为空字符串
7. 品牌组合 (brand_group) - 酒店所属的品牌集团，如万豪、希尔顿等
8. 照片链接 (pic_url) - 人物的照片URL链接，根据上述识别规则提取

## 输出格式
请以严格的JSON格式返回结果，不要添加任何额外解释文字。如果文本中包含多个人员信息，返回JSON数组，每个人员一个JSON对象。如果只有一个人员，也要返回数组格式。

单人员示例：
```json
[
  {
    "name_zh": "张三",
    "name_en": "Zhang San",
    "title_zh": "总经理",
    "title_en": "General Manager",
    "hotel_zh": "北京万豪酒店",
    "hotel_en": "Beijing Marriott Hotel",
    "brand_group": "万豪",
    "pic_url": "https://example.com/photo1.jpg"
  }
]
```

多人员示例：
```json
[
  {
    "name_zh": "张三",
    "name_en": "Zhang San",
    "title_zh": "总经理",
    "title_en": "General Manager",
    "hotel_zh": "北京万豪酒店",
    "hotel_en": "Beijing Marriott Hotel",
    "brand_group": "万豪",
    "pic_url": "https://example.com/photo1.jpg"
  },
  {
    "name_zh": "李四",
    "name_en": "Li Si",
    "title_zh": "市场总监",
    "title_en": "Marketing Director",
    "hotel_zh": "上海希尔顿酒店",
    "hotel_en": "Shanghai Hilton Hotel",
    "brand_group": "希尔顿",
    "pic_url": "https://example.com/photo2.jpg"
  }
]
```

发现有数字编号（**1**、**2**、**3**）分隔，应该提取三个人员的信息，返回包含3个对象的数组。

## 特别提醒
- 请务必扫描整个文档，查找所有数字编号标记的人员信息
- 每个人员信息都要单独提取成一个JSON对象
- 最终返回的数组长度应该等于文档中的人员数量

以下是需要分析的网页Markdown文本内容：

""" + markdown_text
        
        # 调用 Qwen VL Max API
        logging.info("发送网页文本请求到 Qwen VL Max 模型")
        completion = client.chat.completions.create(
            model="qwen-vl-max-latest",
            messages=[
                {
                    "role": "user",
                    "content": [
                        {"type": "text", "text": prompt}
                    ]
                }
            ],
            temperature=0.1,  # 降低温度增加精确性
            response_format={"type": "json_object"}  # 要求输出JSON格式
        )
        
        # 解析响应
        response_content = completion.choices[0].message.content
        logging.info(f"成功从 Qwen 模型获取网页文本响应: {response_content}")
        
        # 直接解析 QWen 返回的 JSON 响应
        try:
            extracted_data = json.loads(response_content)
            logging.info("成功解析 Qwen 网页文本响应中的 JSON")
        except json.JSONDecodeError as e:
            error_msg = f"JSON 解析失败: {str(e)}"
            logging.error(error_msg)
            raise Exception(error_msg)

        # 确保返回的是数组格式
        if not isinstance(extracted_data, list):
            # 如果返回的不是数组，包装成数组
            extracted_data = [extracted_data] if extracted_data else []
        
        # 确保数组中每个人员对象都包含所有必要字段
        required_fields = [
            'name_zh', 'name_en', 'title_zh', 'title_en', 
            'hotel_zh', 'hotel_en', 'brand_group', 'pic_url'
        ]
        
        for person in extracted_data:
            for field in required_fields:
                if field not in person:
                    person[field] = ""
            
            # 为每个人员添加career_path字段
            career_entry = {
                'date': publish_time,
                'hotel_en': person.get('hotel_en', ''),
                'hotel_zh': person.get('hotel_zh', ''),
                'image_path': '',
                'source': 'webpage_extraction',
                'title_en': person.get('title_en', ''),
                'title_zh': person.get('title_zh', '')
            }
            
            person['career_path'] = [career_entry]
            logging.info(f"为人员 {person.get('name_zh', 'Unknown')} 添加了career_path记录: {career_entry}")
        
        # 创建解析任务记录
        try:
            # 生成唯一的任务名称：当前日期 + UUID
            current_date = datetime.now().strftime('%Y%m%d')
            task_uuid = str(uuid.uuid4())[:8]  # 取UUID的前8位
            task_name = f"{current_date}_{task_uuid}"
            
            # 创建解析任务记录
            parse_task = ParseTaskRepository(
                task_name=task_name,
                task_status='completed',  # 解析完成
                task_type='门墩儿新任命',
                task_source='webpage_extraction',
                collection_count=len(extracted_data),  # 采集人数
                parse_count=len(extracted_data),  # 解析人数
                parse_result=extracted_data,  # 解析结果
                created_by='system',
                updated_by='system'
            )
            
            db.session.add(parse_task)
            db.session.commit()
            
            logging.info(f"成功创建解析任务记录: {task_name}, 解析人数: {len(extracted_data)}")
            
        except Exception as db_error:
            db.session.rollback()
            logging.error(f"创建解析任务记录失败: {str(db_error)}", exc_info=True)
            # 不影响主要功能，只记录错误日志
        
        return extracted_data
        
    except Exception as e:
        error_msg = f"Qwen VL Max 模型网页文本解析失败: {str(e)}"
        logging.error(error_msg, exc_info=True)
        raise Exception(error_msg) 

